from distutils.core import setup

"""
pymvrd
------
Motor Vehicle Registration Information Search Portal API

"""


setup(
  name = 'pymvrd',
  packages = ['pymvrd'],
  version = '0.2',
  description = 'Motor Vehicle Registration Information Search Portal Library',
  author = 'Obi Uchenna David',
  author_email = 'daviduchenna@outlook.com',
  url = 'https://github.com/othreecodes/pymvrd', 
  download_url = 'https://github.com/othreecodes/pymvrd/tarball/0.2', 
  keywords = ['vehicle','plate number','registration'], 
  classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'License :: OSI Approved :: MIT License',
        'Topic :: Communications',
        'Topic :: Internet',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ]
)
